#
# spec file for package [TfReg]
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

Name:           TfReg
Version:        6.0
Release:        1.1.1
Summary:        Mesoscopic models for DNA and RNA

License:        GPL-3.0
Group:		Productivity/Scientific/Physics
URL:            https://sites.google.com/site/geraldweberufmg/tfreg
Source0:        tfreg-6.0.tar.bz2

BuildRequires:  gcc-c++ 
BuildRequires:  gsl gsl-devel
BuildRequires:  boost-devel
Requires:  gsl
%if 0%{?suse_version}
BuildRequires:  gcc-fortran 
BuildRequires:  libblas3
Requires:  libblas3
%if 0%{?suse_version} == 1140
BuildRequires:  libboost_filesystem1_44_0
BuildRequires:  lapack liblapack3
Requires:  libboost_filesystem1_44_0 lapack liblapack3
%endif
%if 0%{?suse_version} == 1210
BuildRequires:  libboost_filesystem1_46_1
BuildRequires:  lapack liblapack3
Requires:  libboost_filesystem1_46_1 lapack liblapack3
%endif
%if %{?suse_version} >= 1220
BuildRequires:  lapack-devel liblapack3
Requires: liblapack3
%endif
%if 0%{?suse_version} == 1220 || 0%{?suse_version} == 1230
BuildRequires:  libboost_filesystem1_49_0 libboost_system1_49_0
Requires:  libboost_filesystem1_49_0 libboost_system1_49_0
%endif
%if 0%{?suse_version} == 1310
BuildRequires:  libboost_filesystem1_53_0 libboost_system1_53_0
Requires:  libboost_filesystem1_53_0 libboost_system1_53_0
%endif
%if 0%{?suse_version} == 1320
BuildRequires:  libboost_filesystem1_54_0 libboost_system1_54_0
Requires:  libboost_filesystem1_54_0 libboost_system1_54_0
%endif
#OpenSuSE Leap 15.0
%if 0%{?suse_version} == 1500
BuildRequires:  libboost_filesystem1_66_0-devel libboost_system1_66_0-devel libboost_regex1_66_0-devel
Requires:  libboost_filesystem1_66_0 libboost_system1_66_0 libboost_regex1_66_0
%endif
#OpenSuSE Tumbleweed as of 04/2021
#osc ls -b -r standard -a x86_64 openSUSE:Factory | grep boost
%if 0%{?if_tumbleweed} == 1
BuildRequires:  libboost_filesystem1_75_0-devel libboost_system1_75_0-devel libboost_regex1_75_0-devel
Requires:  libboost_filesystem1_75_0 libboost_system1_75_0 libboost_regex1_75_0
%endif
%endif

#specific script for dealing with file duplicates
%if ! %{defined scientificlinux_version} && ! %{defined centos_version}
BuildRequires:  fdupes
%endif


%if %{defined fedora} || %{defined rhel}
%if 0%{?fedora} < 24
BuildRequires:  gcc-fortran 
%else
BuildRequires:  gcc-gfortran 
%endif
BuildRequires:  boost-filesystem
BuildRequires:  lapack-devel lapack
BuildRequires:  blas
%endif
BuildRequires:  zlib-devel


%description
TfReg implements the calculation of the mesoscopic Peyrard-Bishop Hamiltonians to obtain some
physical properties of DNA and RNA duplexes. The method uses the transfer matrix
technique for the calculation of the classical partition function. 
Also, TfReg calculates the regression of experimental versus predicted melting temperatures using the
equivalent melting index.
Available parameter files cover AT and CG bases for DNA; AU, CG and GU for RNA; single group-I bulges for RNA;
Cy3 and Cy5 attached to DNA; TNA; LNA.

%prep
%setup -q

%build
make 


%install
mkdir -p %{buildroot}/%{_bindir}
install -m 755 tfreg %{buildroot}/%{_bindir}/tfreg
install -m 755 tfreg-salt-regression.pl %{buildroot}/%{_bindir}/tfreg-salt-regression.pl
mkdir -p %{buildroot}/%{_datadir}/%{name}
cp -r examples %{buildroot}/%{_datadir}/%{name}
cp -r data %{buildroot}/%{_datadir}/%{name}

%if ! %{defined scientificlinux_version} && ! %{defined centos_version}
%fdupes -s %{buildroot}/%{_datadir}
%endif

%clean
rm -rf %%{buildroot}

%files
%defattr(-, root, root)
%{_bindir}/tfreg
%{_bindir}/tfreg-salt-regression.pl
%doc doc/tfreg-user-manual.pdf
%doc gpl-3.0.txt
%{_datadir}/%{name}

%changelog
* Wed Apr 07 2021 <gweberbh@gmail.com> 6.0
New LNA and DNA-Mg2+ parameters. Corrections and new example scripts.
* Tue Nov 17 2020 <gweberbh@gmail.com> 5.3
New RNA salt-dependent parameters, new sprediction options. Corrections and new example scripts.
* Mon Jul 13 2020 <gweberbh@gmail.com> 5.2
New parameters for DNA+LNA/DNA and DNA+LNA/RNA. New 3D model.
* Thu Mar 12 2020 <gweberbh@gmail.com> 5.1
New parameters for DNA mismatches.
* Tue Feb 25 2020 <gweberbh@gmail.com> 5.0
New parameters for DNA/TNA hybrids, new features and bug fixes.
* Wed Sep 19 2018 <gweberbh@gmail.com> 4.0
New parameters for DNA/RNA hybrids. Bug fixes. Documentation updates.
* Thu Jul 13 2017 <gweberbh@gmail.com> 3.2
New parameters for Cy3/Cy5-DNA. Fixed bug regarding average opening calculation which in certain circumstances would use periodic boundary conditions. Documentation updates.
* Tue Apr 11 2017 <gweberbh@gmail.com> 3.1
New parameter files for group I RNA bulges.
* Fri Jan 22 2016 <gweberbh@gmail.com> 3.0
Fixed important bug concerning matrix multiplications which affects the average opening profiles, especially for symmetric sequences. This may also affect, although very slightly, the melting index and predicted temperatures. Differences in both cases are around 0.01 or less compared to previous versions of tfreg. Fixed bug from version 2.0 which was generating empty files for option -res=prediction with single sequences. Added new base pair representation of type XY^z which introduces context-dependent base pairs. Added optimized parameters for RNA GU. Linking to the library libboost_regex is now required. Code clean up, removed gbc_exp from C++ name space. Adding version identification, see first printed line when running tfreg. You can now add easily your own model potentials. Example scripts were revised for consistency, in particular they no longer accept the data folder as argument. Alternative data folders should be provided by setting the PREFIX command line variable.
* Wed Dec 17 2014 <gweberbh@gmail.com> 2.0
Corrected harmless bug which was causing the last line of a parameter to be read twice. Added a new model -model=mes. Added new option -res=nncheck. Added optimized parameters for deoxyinosine. Files with extension .ver now have an additional column providing RMS(Delta T).
* Wed Feb 06 2013 <gweberbh@gmail.com> 1.1
Improved user documentation. New script tfreg-salt-regression.pl to generate regression files for different salt concentrations. Corrected bug which caused the unnecessary recalculation of quadrature weights, as a result TfReg now runs much faster.
* Sat Nov 10 2012 <gweberbh@gmail.com> 1.0
First Public Release 
